.. qnum::
   :prefix: 7-11-
   :start: 1


Multiple-Choice Exercises
=========================

.. toctree::
   :maxdepth: 3

   listEasyMC.rst
   listMedMC.rst
   listHardMC.rst
   ssEasyMC.rst
   ssMedMC.rst
   ssHardMC.rst



